{theme=documentation}

\include{"../include.md"}

\title{Icons "with OpenIconic"}

{.alert}
These functions are intended to be used only together with the html view.

[Iconic](https://useiconic.com) is a beautiful icon set.  
It's open source part is prebuilt right into luke and serves currently 223 marks.

To see a list of all available icons, go to: [OpenIconic List](https://useiconic.com/open)

```latex
\icon{headphones} + \icon{musical-note} = \icon{heart}
```

**Results In**  
\icon{headphones} + \icon{musical-note} = \icon{heart}


## Icon List

| Icon | Name |
| :----: | :---- |
| \icon{account-login} | `account-login` |
| \icon{account-logout} | `account-logout` |
| \icon{action-redo} | `action-redo` |
| \icon{action-undo} | `action-undo` |
| \icon{align-center} | `align-center` |
| \icon{align-left} | `align-left` |
| \icon{align-right} | `align-right` |
| \icon{aperture} | `aperture` |
| \icon{arrow-bottom} | `arrow-bottom` |
| \icon{arrow-circle-bottom} | `arrow-circle-bottom` |
| \icon{arrow-circle-left} | `arrow-circle-left` |
| \icon{arrow-circle-right} | `arrow-circle-right` |
| \icon{arrow-circle-top} | `arrow-circle-top` |
| \icon{arrow-left} | `arrow-left` |
| \icon{arrow-right} | `arrow-right` |
| \icon{arrow-thick-bottom} | `arrow-thick-bottom` |
| \icon{arrow-thick-left} | `arrow-thick-left` |
| \icon{arrow-thick-right} | `arrow-thick-right` |
| \icon{arrow-thick-top} | `arrow-thick-top` |
| \icon{arrow-top} | `arrow-top` |
| \icon{audio} | `audio` |
| \icon{audio-spectrum} | `audio-spectrum` |
| \icon{badge} | `badge` |
| \icon{ban} | `ban` |
| \icon{bar-chart} | `bar-chart` |
| \icon{basket} | `basket` |
| \icon{battery-empty} | `battery-empty` |
| \icon{battery-full} | `battery-full` |
| \icon{beaker} | `beaker` |
| \icon{bell} | `bell` |
| \icon{bluetooth} | `bluetooth` |
| \icon{bold} | `bold` |
| \icon{bolt} | `bolt` |
| \icon{book} | `book` |
| \icon{bookmark} | `bookmark` |
| \icon{box} | `box` |
| \icon{briefcase} | `briefcase` |
| \icon{british-pound} | `british-pound` |
| \icon{browser} | `browser` |
| \icon{brush} | `brush` |
| \icon{bug} | `bug` |
| \icon{bullhorn} | `bullhorn` |
| \icon{calculator} | `calculator` |
| \icon{calendar} | `calendar` |
| \icon{camera-slr} | `camera-slr` |
| \icon{caret-bottom} | `caret-bottom` |
| \icon{caret-left} | `caret-left` |
| \icon{caret-right} | `caret-right` |
| \icon{caret-top} | `caret-top` |
| \icon{cart} | `cart` |
| \icon{chat} | `chat` |
| \icon{check} | `check` |
| \icon{chevron-bottom} | `chevron-bottom` |
| \icon{chevron-left} | `chevron-left` |
| \icon{chevron-right} | `chevron-right` |
| \icon{chevron-top} | `chevron-top` |
| \icon{circle-check} | `circle-check` |
| \icon{circle-x} | `circle-x` |
| \icon{clipboard} | `clipboard` |
| \icon{clock} | `clock` |
| \icon{cloud} | `cloud` |
| \icon{cloud-download} | `cloud-download` |
| \icon{cloud-upload} | `cloud-upload` |
| \icon{cloudy} | `cloudy` |
| \icon{code} | `code` |
| \icon{cog} | `cog` |
| \icon{collapse-down} | `collapse-down` |
| \icon{collapse-left} | `collapse-left` |
| \icon{collapse-right} | `collapse-right` |
| \icon{collapse-up} | `collapse-up` |
| \icon{command} | `command` |
| \icon{comment-square} | `comment-square` |
| \icon{compass} | `compass` |
| \icon{contrast} | `contrast` |
| \icon{copywriting} | `copywriting` |
| \icon{credit-card} | `credit-card` |
| \icon{crop} | `crop` |
| \icon{dashboard} | `dashboard` |
| \icon{data-transfer-download} | `data-transfer-download` |
| \icon{data-transfer-upload} | `data-transfer-upload` |
| \icon{delete} | `delete` |
| \icon{dial} | `dial` |
| \icon{document} | `document` |
| \icon{dollar} | `dollar` |
| \icon{double-quote-sans-left} | `double-quote-sans-left` |
| \icon{double-quote-sans-right} | `double-quote-sans-right` |
| \icon{double-quote-serif-left} | `double-quote-serif-left` |
| \icon{double-quote-serif-right} | `double-quote-serif-right` |
| \icon{droplet} | `droplet` |
| \icon{eject} | `eject` |
| \icon{elevator} | `elevator` |
| \icon{ellipses} | `ellipses` |
| \icon{envelope-closed} | `envelope-closed` |
| \icon{envelope-open} | `envelope-open` |
| \icon{euro} | `euro` |
| \icon{excerpt} | `excerpt` |
| \icon{expand-down} | `expand-down` |
| \icon{expand-left} | `expand-left` |
| \icon{expand-right} | `expand-right` |
| \icon{expand-up} | `expand-up` |
| \icon{external-link} | `external-link` |
| \icon{eye} | `eye` |
| \icon{eyedropper} | `eyedropper` |
| \icon{file} | `file` |
| \icon{fire} | `fire` |
| \icon{flag} | `flag` |
| \icon{flash} | `flash` |
| \icon{folder} | `folder` |
| \icon{fork} | `fork` |
| \icon{fullscreen-enter} | `fullscreen-enter` |
| \icon{fullscreen-exit} | `fullscreen-exit` |
| \icon{globe} | `globe` |
| \icon{graph} | `graph` |
| \icon{grid-four-up} | `grid-four-up` |
| \icon{grid-three-up} | `grid-three-up` |
| \icon{grid-two-up} | `grid-two-up` |
| \icon{hard-drive} | `hard-drive` |
| \icon{header} | `header` |
| \icon{headphones} | `headphones` |
| \icon{heart} | `heart` |
| \icon{home} | `home` |
| \icon{image} | `image` |
| \icon{inbox} | `inbox` |
| \icon{infinity} | `infinity` |
| \icon{info} | `info` |
| \icon{italic} | `italic` |
| \icon{justify-center} | `justify-center` |
| \icon{justify-left} | `justify-left` |
| \icon{justify-right} | `justify-right` |
| \icon{key} | `key` |
| \icon{laptop} | `laptop` |
| \icon{layers} | `layers` |
| \icon{lightbulb} | `lightbulb` |
| \icon{link-broken} | `link-broken` |
| \icon{link-intact} | `link-intact` |
| \icon{list} | `list` |
| \icon{list-rich} | `list-rich` |
| \icon{location} | `location` |
| \icon{lock-locked} | `lock-locked` |
| \icon{lock-unlocked} | `lock-unlocked` |
| \icon{loop} | `loop` |
| \icon{loop-circular} | `loop-circular` |
| \icon{loop-square} | `loop-square` |
| \icon{magnifying-glass} | `magnifying-glass` |
| \icon{map} | `map` |
| \icon{map-marker} | `map-marker` |
| \icon{media-pause} | `media-pause` |
| \icon{media-play} | `media-play` |
| \icon{media-record} | `media-record` |
| \icon{media-skip-backward} | `media-skip-backward` |
| \icon{media-skip-forward} | `media-skip-forward` |
| \icon{media-step-backward} | `media-step-backward` |
| \icon{media-step-forward} | `media-step-forward` |
| \icon{media-stop} | `media-stop` |
| \icon{medical-cross} | `medical-cross` |
| \icon{menu} | `menu` |
| \icon{microphone} | `microphone` |
| \icon{minus} | `minus` |
| \icon{monitor} | `monitor` |
| \icon{moon} | `moon` |
| \icon{move} | `move` |
| \icon{musical-note} | `musical-note` |
| \icon{paperclip} | `paperclip` |
| \icon{pencil} | `pencil` |
| \icon{people} | `people` |
| \icon{person} | `person` |
| \icon{phone} | `phone` |
| \icon{pie-chart} | `pie-chart` |
| \icon{pin} | `pin` |
| \icon{play-circle} | `play-circle` |
| \icon{plus} | `plus` |
| \icon{power-standby} | `power-standby` |
| \icon{print} | `print` |
| \icon{project} | `project` |
| \icon{pulse} | `pulse` |
| \icon{puzzle-piece} | `puzzle-piece` |
| \icon{question-mark} | `question-mark` |
| \icon{rain} | `rain` |
| \icon{random} | `random` |
| \icon{reload} | `reload` |
| \icon{resize-both} | `resize-both` |
| \icon{resize-height} | `resize-height` |
| \icon{resize-width} | `resize-width` |
| \icon{rss} | `rss` |
| \icon{rss-alt} | `rss-alt` |
| \icon{script} | `script` |
| \icon{share} | `share` |
| \icon{share-boxed} | `share-boxed` |
| \icon{shield} | `shield` |
| \icon{signal} | `signal` |
| \icon{signpost} | `signpost` |
| \icon{sort-ascending} | `sort-ascending` |
| \icon{sort-descending} | `sort-descending` |
| \icon{spreadsheet} | `spreadsheet` |
| \icon{star} | `star` |
| \icon{sun} | `sun` |
| \icon{tablet} | `tablet` |
| \icon{tag} | `tag` |
| \icon{tags} | `tags` |
| \icon{target} | `target` |
| \icon{task} | `task` |
| \icon{terminal} | `terminal` |
| \icon{text} | `text` |
| \icon{thumb-down} | `thumb-down` |
| \icon{thumb-up} | `thumb-up` |
| \icon{timer} | `timer` |
| \icon{transfer} | `transfer` |
| \icon{trash} | `trash` |
| \icon{underline} | `underline` |
| \icon{vertical-align-bottom} | `vertical-align-bottom` |
| \icon{vertical-align-center} | `vertical-align-center` |
| \icon{vertical-align-top} | `vertical-align-top` |
| \icon{video} | `video` |
| \icon{volume-high} | `volume-high` |
| \icon{volume-low} | `volume-low` |
| \icon{volume-off} | `volume-off` |
| \icon{warning} | `warning` |
| \icon{wifi} | `wifi` |
| \icon{wrench} | `wrench` |
| \icon{x} | `x` |
| \icon{yen} | `yen` |
| \icon{zoom-in} | `zoom-in` |
| \icon{zoom-out} | `zoom-out` |
